==> openliberty-24.0.0.6-src.zip: open-liberty-gm-24.0.0.6/dev/com.ibm.ws.jaxrs.2.0.client_fat/fat/src/com/ibm/ws/jaxrs20/client/fat/test/SimpleSSLMultipleServersTest.java <==
/*******************************************************************************
 * Copyright (c) 2022 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.jaxrs20.client.fat.test;

import static org.junit.Assert.assertNotNull;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.runner.RunWith;

import com.ibm.websphere.simplicity.ShrinkHelper;

import componenttest.annotation.Server;
import componenttest.annotation.TestServlet;
import componenttest.custom.junit.runner.FATRunner;
import componenttest.topology.impl.LibertyServer;
import componenttest.topology.utils.FATServletClient;
import io.openliberty.jaxrs.client.fat.simpleSSL.multi.servlet.SimpleSSLMultipleServersClientTestServlet;

@RunWith(FATRunner.class)
public class SimpleSSLMultipleServersTest extends FATServletClient {

    private static final String appName = "simpleSSL";

    @Server("com.ibm.ws.jaxrs.2.0.client.fat.SimpleSSLMultiServerTestA")
    @TestServlet(servlet = SimpleSSLMultipleServersClientTestServlet.class, contextRoot = appName)
    public static LibertyServer server;

    @Server("com.ibm.ws.jaxrs.2.0.client.fat.SimpleSSLMultiServerTestB")
    public static LibertyServer server2;

    @BeforeClass
    public static void setup() throws Exception {
        // Build an application and export it to the dropins directory
        ShrinkHelper.defaultDropinApp(server, appName, "io.openliberty.jaxrs.client.fat.simpleSSL.multi.servlet");
        ShrinkHelper.defaultDropinApp(server2, appName, "io.openliberty.jaxrs.client.fat.simpleSSL");

        // Make sure we don't fail because we try to start an
        // already started server
        try {
            server.startServer("server.log", true);
            assertNotNull("The server did not start", server.waitForStringInLog("CWWKF0011I"));
            assertNotNull("FeatureManager did not report update was complete", server.waitForStringInLog("CWWKF0008I"));

            /*
             * You must set the following in the server.xml when calling useSecondaryHTTPPort()
             *
             *     <httpEndpoint id="defaultHttpEndpoint"
             *         host="*"
             *         httpPort="${bvt.prop.HTTP_secondary}"
             *         httpsPort="${bvt.prop.HTTP_secondary.secure}"/>
             */
            server2.useSecondaryHTTPPort();
            server2.startServer("server.log", true);
            assertNotNull("The server did not start", server2.waitForStringInLog("CWWKF0011I"));
            assertNotNull("FeatureManager did not report update was complete", server2.waitForStringInLog("CWWKF0008I"));
        } catch (Exception e) {
            System.out.println(e.toString());
        }
    }

    @AfterClass
    public static void teardown() throws Exception {
        if (server != null) {
            server.stopServer("CWWKE1102W");  //ignore server quiesce timeouts due to slow test machines
        }
        if (server2 != null) {
            server2.stopServer("CWWKE1102W");  //ignore server quiesce timeouts due to slow test machines
        }
    }

    @Before
    public void beforeTest() {}

    @After
    public void afterTest() {}
}

==> openliberty-24.0.0.12-src.zip: open-liberty-gm-24.0.0.12/dev/com.ibm.ws.jaxrs.2.0.client_fat/fat/src/com/ibm/ws/jaxrs20/client/fat/test/SimpleSSLMultipleServersTest.java <==
/*******************************************************************************
 * Copyright (c) 2022 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.jaxrs20.client.fat.test;

import static org.junit.Assert.assertNotNull;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.runner.RunWith;

import com.ibm.websphere.simplicity.ShrinkHelper;

import componenttest.annotation.Server;
import componenttest.annotation.TestServlet;
import componenttest.custom.junit.runner.FATRunner;
import componenttest.topology.impl.LibertyServer;
import componenttest.topology.utils.FATServletClient;
import io.openliberty.jaxrs.client.fat.simpleSSL.multi.servlet.SimpleSSLMultipleServersClientTestServlet;

@RunWith(FATRunner.class)
public class SimpleSSLMultipleServersTest extends FATServletClient {

    private static final String appName = "simpleSSL";

    @Server("com.ibm.ws.jaxrs.2.0.client.fat.SimpleSSLMultiServerTestA_no_default")
    @TestServlet(servlet = SimpleSSLMultipleServersClientTestServlet.class, contextRoot = appName)
    public static LibertyServer server;

    @Server("com.ibm.ws.jaxrs.2.0.client.fat.SimpleSSLMultiServerTestB")
    public static LibertyServer server2;

    @BeforeClass
    public static void setup() throws Exception {
        // Build an application and export it to the dropins directory
        ShrinkHelper.defaultDropinApp(server, appName, "io.openliberty.jaxrs.client.fat.simpleSSL.multi.servlet");
        ShrinkHelper.defaultDropinApp(server2, appName, "io.openliberty.jaxrs.client.fat.simpleSSL");
        ShrinkHelper.defaultDropinApp(server2, appName + "2", "io.openliberty.jaxrs.client.fat.simpleSSL");

        // Make sure we don't fail because we try to start an
        // already started server
        try {
            server.startServer("server.log", true);
            assertNotNull("The server did not start", server.waitForStringInLog("CWWKF0011I"));
            assertNotNull("FeatureManager did not report update was complete", server.waitForStringInLog("CWWKF0008I"));

            /*
             * You must set the following in the server.xml when calling useSecondaryHTTPPort()
             *
             *     <httpEndpoint id="defaultHttpEndpoint"
             *         host="*"
             *         httpPort="${bvt.prop.HTTP_secondary}"
             *         httpsPort="${bvt.prop.HTTP_secondary.secure}"/>
             */
            server2.useSecondaryHTTPPort();
            server2.startServer("server.log", true);
            assertNotNull("The server did not start", server2.waitForStringInLog("CWWKF0011I"));
            assertNotNull("FeatureManager did not report update was complete", server2.waitForStringInLog("CWWKF0008I"));
        } catch (Exception e) {
            System.out.println(e.toString());
        }
    }

    @AfterClass
    public static void teardown() throws Exception {
        if (server != null) {
            server.stopServer("CWWKE1102W");  //ignore server quiesce timeouts due to slow test machines
        }
        if (server2 != null) {
            server2.stopServer("CWWKE1102W");  //ignore server quiesce timeouts due to slow test machines
        }
    }

    @Before
    public void beforeTest() {}

    @After
    public void afterTest() {}
}
